configurationtools.AbjadConfig
==============================

.. inheritance-diagram:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig
   :private-bases:

.. autoclass:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.ABJAD_CONFIG_DIRECTORY_PATH

.. autoattribute:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.ABJAD_CONFIG_FILE_PATH

.. autoattribute:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.ABJAD_EXPERIMENTAL_PATH

.. autoattribute:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.ABJAD_OUTPUT_PATH

.. autoattribute:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.ABJAD_PATH

.. autoattribute:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.ABJAD_ROOT_PATH

.. autoattribute:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.HOME_PATH

.. autoattribute:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Methods
-------

.. automethod:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.clear

    Inherited from :py:class:`_abcoll.MutableMapping`

.. automethod:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.get

    Inherited from :py:class:`_abcoll.Mapping`

.. automethod:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.get_config_spec

.. automethod:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.get_initial_comment

.. automethod:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.get_option_comments

.. automethod:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.get_option_definitions

.. automethod:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.get_option_specs

.. automethod:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.items

    Inherited from :py:class:`_abcoll.Mapping`

.. automethod:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.iteritems

    Inherited from :py:class:`_abcoll.Mapping`

.. automethod:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.iterkeys

    Inherited from :py:class:`_abcoll.Mapping`

.. automethod:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.itervalues

    Inherited from :py:class:`_abcoll.Mapping`

.. automethod:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.keys

    Inherited from :py:class:`_abcoll.Mapping`

.. automethod:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.pop

    Inherited from :py:class:`_abcoll.MutableMapping`

.. automethod:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.popitem

    Inherited from :py:class:`_abcoll.MutableMapping`

.. automethod:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.setdefault

    Inherited from :py:class:`_abcoll.MutableMapping`

.. automethod:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.update

    Inherited from :py:class:`_abcoll.MutableMapping`

.. automethod:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.values

    Inherited from :py:class:`_abcoll.Mapping`

Special Methods
---------------

.. automethod:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.__contains__

    Inherited from :py:class:`_abcoll.Mapping`

.. automethod:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.__delitem__

.. automethod:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.__eq__

    Inherited from :py:class:`_abcoll.Mapping`

.. automethod:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.__getitem__

.. automethod:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.__iter__

.. automethod:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.__len__

.. automethod:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.__ne__

    Inherited from :py:class:`_abcoll.Mapping`

.. automethod:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.__repr__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.__setitem__
